User Guide
------------

The Trio-MySQL user guide explains how to install Trio-MySQL and how to contribute to
the library as a developer.


.. toctree::
  :maxdepth: 1

  installation
  examples
  resources
  development
